@@ -127,6 +127,10 @@ class Request:
         timeout (int): Individual timeout for this request
 
         callback (callable): Synchronous callback that takes the content of the response as the only argument. Should also return content.
+
+        _verify_ssl (boolean): Defaults to True.
+
+        upload_file_content_type (str): Optional content-type header string. In case you don't want to use the default application/octet-stream (Or whatever is auto-detected by your transport handler)
         """
 
     def __init__(
@@ -141,6 +145,8 @@ class Request:
         media_download=None,
         timeout=None,
         callback=None,
+        _verify_ssl=True,
+        upload_file_content_type=None,
     ):
         self.method = method
         self.url = url
@@ -155,6 +161,8 @@ class Request:
         self.media_download = media_download
         self.timeout = timeout
         self.callback = callback
+        self._verify_ssl = _verify_ssl
+        self.upload_file_content_type = upload_file_content_type
 
     def _add_query_param(self, query: dict):
         url = self.url
