@@ -2,7 +2,7 @@ __all__ = ["GoogleAPI", "Resource", "Method"]
 
 import re
 import warnings
-from urllib.parse import urlencode
+from urllib.parse import urlencode, quote_plus
 from functools import wraps
 from typing import List, Generic, TypeVar
 
@@ -580,6 +580,9 @@ class Method:
             if validate is True:
                 self._validate_url(sorted_required_path_params)
 
+            for k, v in sorted_required_path_params.items():
+                sorted_required_path_params[k] = quote_plus(v)
+
             # Build full path
             # replace named placeholders with empty ones. e.g. {param} --> {}
             # Why? Because some endpoints have different names in their url path placeholders than in their parameter defenitions
